@@ -2,8 +2,8 @@ package MooseX::Getopt::GLD;
 BEGIN {
   $MooseX::Getopt::GLD::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $MooseX::Getopt::GLD::VERSION = '0.36';
+{
+  $MooseX::Getopt::GLD::VERSION = '0.38';
 }
 # ABSTRACT: A Moose role for processing command line options with Getopt::Long::Descriptive
 
@@ -106,6 +106,10 @@ MooseX::Getopt::GLD - A Moose role for processing command line options with Geto
 
   with 'MooseX::Getopt::GLD';
 
+  # or
+
+  with 'MooseX::Getopt::GLD' => { getopt_conf => [ 'pass_through', ... ] };
+
   has 'out' => (is => 'rw', isa => 'Str', required => 1);
   has 'in'  => (is => 'rw', isa => 'Str', required => 1);
 
@@ -122,6 +126,13 @@ MooseX::Getopt::GLD - A Moose role for processing command line options with Geto
   ## on the command line
   % perl my_app_script.pl -in file.input -out file.dump
 
+=head1 OPTIONS
+
+This role is a parameterized role. It accepts one configuration parameter,
+C<getopt_conf>. This parameter is an ArrayRef of strings, which are
+L<Getopt::Long> configuraion options (see "Configuring Getopt::Long" in
+L<Getopt::Long>)
+
 =head1 AUTHORS
 
 =over 4
